# Project

This is my simple python project, which could do some simple stuff, like:
    - converting a text
    - logging
    - managing files
    - reading os data
    - sending data
    - ping ips
    - ping ports
    - create zip
    - modify registry entries
    - calculate some stuff
    - overtake the keyboard or the mouse
    - creating folders
    - managing ctk windows
    - checking some stuff
    - checking for wifi
    - ...

However, this project is very simple, but effective.


## Settings

You can manage some things in the settings file of the project,
which is directly in the parent folder of it.